==> CGGoogleMaps-2.0.3.tar.gz: CGGoogleMaps/lang/ext/nl_NL.php <==
<?php
$lang['address'] = 'Adres';
$lang['add_category'] = 'Voeg Categorie toe';
$lang['add_icon'] = 'Voeg Pictogram toe';
$lang['add_map'] = 'Voeg kaart toe';
$lang['add_map_point'] = 'Voeg een punt op de kaart toe';
$lang['add_point_for_map'] = 'Voeg punt toe aan kaart &quot;%s&quot;';
$lang['anchor_x'] = 'Anchor X pixel locatie';
$lang['anchor_y'] = 'Anchor Y pixel locatie';
$lang['ask_delete_icon'] = 'Weet u zeker dat u dit pictogram wilt verwijderen van de lijst? (er worden g&eacute;&eacute;n bestanden gewist)';
$lang['ask_reset_icons'] = 'Weet u zeker dat u alle pictogrammen wilt verwijderen en wil terug gaan naar de standaaard instellingen?';
$lang['cancel'] = 'Annuleren';
$lang['category_maptemplate'] = 'Categorie Overzicht Sjabloon';
$lang['center_lat'] = 'Centreer Breedtegraad';
$lang['center_lon'] = 'Centreer Lengtegraad';
$lang['click'] = 'Klik';
$lang['combine_points'] = 'Combine individual markers that are within range';
$lang['combined_points_icon'] = 'Icon om te gebruiken bij gecombineerde punten';
$lang['controls'] = 'Bedieningsknoppen';
$lang['controls_size'] = 'Grootte van bedieningsknoppen';
$lang['default'] = 'Standaard';
$lang['default_templates'] = 'Standaard sjablonen';
$lang['delete'] = 'Verwijder';
$lang['delete_icon'] = 'Verwijder deze pictogram';
$lang['delete_map'] = 'Verwijder Kaart';
$lang['delete_map_point'] = 'Verwijder punt van kaart';
$lang['description'] = 'Omschrijving';
$lang['directions'] = 'Laat bestemming zien';
$lang['edit'] = 'Wijzig';
$lang['edit_icon'] = 'Verander deze pictogram';
$lang['edit_map'] = 'Bewerk kaart';
$lang['edit_map_point'] = 'Bewerk kaart punt';
$lang['edit_map_points'] = 'Bewerk kaart punten';
$lang['edit_points_for_map'] = 'Bewerk punten voor kaart &quot;%s&quot;';
$lang['error_cannotdelete'] = 'Dit kan niet worden verwijderd';
$lang['error_invalidparams'] = 'Een of meerdere parameters missen of zijn ongeldig';
$lang['error_nameexists'] = 'Een item met deze naam bestaat al';
$lang['error_noapikey'] = 'De Google API Key is niet ingevuld';
$lang['error_noapikey2'] = 'De Google API Key is leeg.  De module zal niet goed functioneren tot dat deze functie is ingesteld met de gegevens die Google heeft aangedragen.';
$lang['error_notfound'] = 'De gevraagde item kon niet worden gevonden';
$lang['error_permissiondenied'] = 'U heeft niet de benodigde bevoegdheden voor deze actie';
$lang['friendlyname'] = 'Calguys Google Maps ';
$lang['google_api_key'] = 'Google API sleutel';
$lang['help'] = '<h3>What does this do </h3>
<p>This is a replacement (in progress) for tsw&#039;s googlemaps module that allows users to easily create google maps, whilst allowing atomic permissions so that only authorized users have certain abilities.  It also allows for dynamic geolocating (with caching) so that you can specify a location by address instead of by latitude and longitude.</p>
<p>This module allows multiple maps to be displayed on a single page, and multiple &#039;markers&#039; or points on each map, so that it can be used in a way similar to frapper.</p>
<h3>Features:</h3>
<ul>
  <li>Static map creation using a full admin interface for managing maps and markers within a map.</li>
  <li>Flexible marker icon management.</li>
  <li>The ability to dynamically add markers given data from an outside point <em>(see {cggm_add_dynpoint})</em>
  <li>The ability to group markers that are within a lat/long radius to a single marker with a special icon.</li>
  <li>Dynamic icon control for each marker point.</li>
</ul>
<h3>How Do I Use It?</h3>
<ul>
<li>Install the module via the normal methods</li>
<li>Setup your users and groups with the appropriate permissions:
  <ul>
    <li>The &#039;Manage Maps&#039; Permission allows administrators to add/edit and delete maps</li>
    <li>The &#039;Manage Map Locations&#039; permission allows administrators to add/edit/delete points within a map</li>
  </ul>
</li>
<li>Create a map.  Give the map a name, and adjust the paramters of the particular map to meet your liking</p>
<li>Mark one of your maps as default, by clicking on the red &#039;X&#039; beside a particular map.  This is useful if you don&#039;t specify the &#039;map&#039; parameter on the tag.</li>
<li>Create one or more points within the map, either by specifying a latitude and longitude, or with an address.</li>
<li>Add the {CGGoogleMaps} tag inside the content block of a page, or inside a page template.  Then you&#039;re finished.</li>
</ul>
<br/>
<h3>Adding Points to a Map Dynamically</h3>
<p>You can use smarty to add points to a module dynamically.  You can use this functionality to build a frappr like map with multiple points that are controlled dynamically from another module (like CompanyDirectory or FrontEndUsers).</p>
<h4>The {cggm_add_dynpoint} Smarty Plugin</h4>
<p>This smarty plugin <em>(only available when CGGoogleMaps is installed)</em> allows adding a point dynamically to a specified map.</p>
<h5>Parameters:<h5>
  <ul> 
<li><strong>required</strong> - map : The ID of the map to add the point to</li>
<li><strong>required</strong> - name : The name of the point to add</li>
<li><em>optional</em> - description : The HTML content to show in the popup bubble</li>
<li><em>optional</em> - address : The address of the location you are adding.</li>
<li><em>optional</em> - lat : The latitude of the location you are adding.</li>
<li><em>optional</em> - long : The longitude of the location you are adding.</li>
<li><em>optional</em> - icon : The name of an icon to use for this point.</li>
<li><em>optional</em> - tooltip : Title text to display when hovering a point</li>
<li><em>optional</em> - sidebar_class : Optional class to associate with the sidebar list item for this point.</li>
<li><em>optional</em> - sidebar_html : Optional text to include for this marker on the sidebar.</li>
  </ul>
<br/>
<p><strong>Note:</strong> Either the lat and long parameters must be specified, or the address.</p>
<p><strong>Note:</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
</ul>';
$lang['height'] = 'Hoogte';
$lang['help_anchor_location'] = '<strong>Opmerking:</strong> Anchor locaties specificeren de pixel locatie (in relatie tot de linkerboven hoek van de afbeelding) waar de pictogram moet komen als markeerpunt. Als er geen waarde is gegeven, wordt het midden van de pictogram gebruikt';
$lang['help_icon_url'] = 'Benoem de URL van de ge&uuml;ploade PNG afbeelding.  Deze afbeelding mag niet groter zijn dan 32x32px, en moet transparant zijn. De URL moet vanuit de root van uw website worden benoemd';
$lang['help_param_defer'] = 'Specify that all javascript tags should have the defer attribute set.  This may be useful for problems with IE7 and IE8 where Internet explorer tries to execute javascript on an incompletely rendered page. ';
$lang['help_param_map'] = 'Specificeer een ID of kaartnaam voor het weergeven van de Google Map. Als deze parameter niet wordt opgegeven, dan wordt de standaard map gebruikt.';
$lang['help_param_maptemplate'] = 'Geef de naam op van een bestaande, niet standaard (default) map sjabloon om te gebruiken voor deze output. Als deze parameter niet gespecificeerd is, zal de huidige als standaard gekenmerkte sjabloon toegepast worden.';
$lang['hybrid'] = 'Kruising';
$lang['id'] = 'Id ';
$lang['icon'] = 'Pictogram';
$lang['info_address_latlong'] = 'Opmerking: Geef <strong>OF</strong> een adres in <strong>OF</strong> een breedtegraad en lengtegraad.  Als beide zijn ingegeven, zal breedtegraad/lengtegraad worden gebruikt.';
$lang['info_anchor_x'] = 'Infoscherm Anchor X pixel locatie';
$lang['info_anchor_y'] = 'Infoscherm Anchor Y pixel locatie';
$lang['info_combine_points'] = 'If selected, points that are within a specified radius of each other will be combined into one marker on the map.  This functionality is useful if multiple entries exist at the same (or almost the same) coordinates, to ease in selection.  This functionality is independant of the map zoom level.  ';
$lang['info_point_combine_fudge'] = 'The smaller the radius means that fewer points will be combined into one map marker.  Negative values are invalid.';
$lang['info_sysdflt_map_template'] = 'Standaard systeem map sjabloon';
$lang['info_sysdflt_template'] = 'Dit formulier geeft de mogelijkheid om de inhoud te specificeren die zal worden getoond als je een nieuw sjabloon van dit type aanmaakt. Het wijzigen van de inhoud zal geen direct effect hebben op je website.';
$lang['info_window'] = 'Toon Informatie Venster';
$lang['info_trigger'] = 'Informatie Venster Trigger ';
$lang['large'] = 'Groot';
$lang['latitude'] = 'Breedtegraad';
$lang['latlong'] = 'Breedtegraad / Lengtegraad';
$lang['location'] = 'Locatie';
$lang['longitude'] = 'Lengtegraad';
$lang['make_default'] = 'Gebruik standaard dit pictogram';
$lang['marker_categories'] = 'Marker Categorie&euml;n';
$lang['marker_icons'] = 'Markeer Pictogram';
$lang['map'] = 'Kaart';
$lang['maps'] = 'Kaarten';
$lang['maptemplate_addedit'] = 'toevoegen/wijzigen map sjabloon';
$lang['map_name'] = 'Kaart naam';
$lang['map_template'] = 'Map Sjabloon';
$lang['map_templates'] = 'Map Sjablonen';
$lang['moddescription'] = 'Module om Google maps te maken';
$lang['mouseover'] = 'MuisOver';
$lang['msg_default_icon_uchanged'] = 'De standaard pictogram is gewijzigd';
$lang['msg_icons_reset'] = 'De pictogrammen zijn terug naar de standaard instellingen';
$lang['msg_icon_removed'] = 'Pictogram verwijderd van de database.  Er zijn geen bestanden verwijderd';
$lang['msg_icon_updated'] = 'Pictogram informatie is gewijzigd';
$lang['name'] = 'Naam';
$lang['points'] = 'Punten';
$lang['point_combine_fudge'] = 'Benoem een radius die aangeeft wanneer punten moeten worden gecombineerd.';
$lang['point_name'] = 'Punt naam';
$lang['point_type'] = 'Aanwijzer Type';
$lang['postinstall'] = 'CGGoogleMaps is ge&iuml;nstalleerd';
$lang['postuninstall'] = 'De CGGoogleMaps module en alle relevante bestanden zijn verwijderd';
$lang['preferences'] = 'Eigenschappen';
$lang['really_uninstall'] = 'Weet je zeker dat je deze module wilt verwijderen?';
$lang['reset'] = 'Herstel';
$lang['reset_icons'] = 'Reset pictogrammen';
$lang['satellite'] = 'Sateliet';
$lang['set_dflt_map'] = 'Zet kaart als standaard';
$lang['sidebar'] = 'Geef Sidebar weer';
$lang['sidebar_maptemplate'] = 'Zij Kolom Sjabloon';
$lang['small'] = 'Klein';
$lang['submit'] = 'Verzend';
$lang['tab_settings'] = 'Instellingen';
$lang['tab_maptemplate'] = 'Map Sjabloon';
$lang['text'] = 'Tekst';
$lang['type'] = 'Soort';
$lang['type_controls'] = 'Geef typebesturingsknoppen weer';
$lang['url'] = 'Url';
$lang['width'] = 'Breedte';
$lang['zoom'] = 'Inzoom level';
$lang['zoom_encompass'] = 'Inzoom omgeving';
$lang['utma'] = '156861353.1335698708.1284586217.1290620330.1290627712.440';
$lang['utmz'] = '156861353.1290526978.432.46.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=http://www.cmsmadesimple.org/index.php';
$lang['qca'] = 'P0-1551306179-1284586216711';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> CGGoogleMaps-2.1.3.tar.gz: CGGoogleMaps/lang/ext/nl_NL.php <==
<?php
$lang['address'] = 'Adres';
$lang['add_category'] = 'Voeg Categorie toe';
$lang['add_icon'] = 'Voeg Pictogram toe';
$lang['add_map'] = 'Voeg kaart toe';
$lang['add_map_point'] = 'Voeg een punt op de kaart toe';
$lang['add_point_for_map'] = 'Voeg punt toe aan kaart &quot;%s&quot;';
$lang['aerial'] = 'Antenne';
$lang['anchor_x'] = 'Anchor X pixel locatie';
$lang['anchor_y'] = 'Anchor Y pixel locatie';
$lang['apply'] = 'Toepassen';
$lang['ask_delete_icon'] = 'Weet u zeker dat u dit pictogram wilt verwijderen van de lijst? (er worden g&eacute;&eacute;n bestanden gewist)';
$lang['ask_reset_icons'] = 'Weet u zeker dat u alle pictogrammen wilt verwijderen en wil terug gaan naar de standaaard instellingen?';
$lang['cancel'] = 'Annuleren';
$lang['category_template'] = 'Categorieweergave sjabloon';
$lang['center_lat'] = 'Centreer Breedtegraad';
$lang['center_lon'] = 'Centreer Lengtegraad';
$lang['click'] = 'Klik';
$lang['combine_points'] = 'Combineer individuele markers die binnen dit bereik zijn';
$lang['combined_points_icon'] = 'Icon om te gebruiken bij gecombineerde punten';
$lang['controls'] = 'Bedieningsknoppen';
$lang['controls_size'] = 'Grootte van bedieningsknoppen';
$lang['default'] = 'Standaard';
$lang['default_icon'] = 'Standaard pictogram';
$lang['default_templates'] = 'Standaard sjablonen';
$lang['delete'] = 'Verwijder';
$lang['delete_icon'] = 'Verwijder deze pictogram';
$lang['delete_map'] = 'Verwijder Kaart';
$lang['delete_map_point'] = 'Verwijder punt van kaart';
$lang['description'] = 'Omschrijving';
$lang['directions'] = 'Laat bestemming zien';
$lang['directions_dest'] = 'Waar bestemmingen moeten worden getekend';
$lang['directions_units'] = 'Directions Units';
$lang['dirform_maptemplate'] = 'Directions Form Template';
$lang['dropdown'] = 'Dropdown ';
$lang['edit'] = 'Wijzig';
$lang['edit_category'] = 'Edit Marker Category';
$lang['edit_icon'] = 'Verander deze pictogram';
$lang['edit_map'] = 'Bewerk kaart';
$lang['edit_map_point'] = 'Bewerk kaart punt';
$lang['edit_map_points'] = 'Bewerk kaart punten';
$lang['edit_points_for_map'] = 'Bewerk punten voor kaart &quot;%s&quot;';
$lang['error_browser_incompatible'] = 'Deze browser is niet in staat om kaarten weer te gegeven van Google';
$lang['error_cannotdelete'] = 'Dit kan niet worden verwijderd';
$lang['error_deletecategory'] = 'Probleem met verwijderen van categorie';
$lang['error_invalidparams'] = 'Een of meerdere parameters missen of zijn ongeldig';
$lang['error_mapelem_notfound'] = 'Kaartelement niet gevonden';
$lang['error_nameexists'] = 'Een item met deze naam bestaat al';
$lang['error_noapikey'] = 'De Google API Key is niet ingevuld';
$lang['error_noapikey2'] = 'De Google API Key is leeg.  De module zal niet goed functioneren tot dat deze functie is ingesteld met de gegevens die Google heeft aangedragen.';
$lang['error_notfound'] = 'De gevraagde item kon niet worden gevonden';
$lang['error_permissiondenied'] = 'U heeft niet de benodigde bevoegdheden voor deze actie';
$lang['friendlyname'] = 'Calguys Google Maps ';
$lang['from'] = 'Formulier';
$lang['get_directions'] = 'Verkrijg bestemmingen';
$lang['google_api_key'] = 'Google API sleutel';
$lang['help'] = '<h3>What does this do </h3>
<p>This is a replacement (in progress) for tsw&#039;s googlemaps module that allows users to easily create google maps, whilst allowing atomic permissions so that only authorized users have certain abilities.  It also allows for dynamic geolocating (with caching) so that you can specify a location by address instead of by latitude and longitude.</p>
<p>This module allows multiple maps to be displayed on a single page, and multiple &#039;markers&#039; or points on each map, so that it can be used in a way similar to frapper.</p>
<h3>Features:</h3>
<ul>
  <li>Static map creation using a full admin interface for managing maps and markers within a map.</li>
  <li>Flexible marker icon management.</li>
  <li>The ability to dynamically add markers given data from an outside point <em>(see {cggm_add_dynpoint})</em>
  <li>The ability to group markers that are within a lat/long radius to a single marker with a special icon.</li>
  <li>Dynamic icon control for each marker point.</li>
</ul>
<h3>How Do I Use It?</h3>
<ul>
<li>Install the module via the normal methods</li>
<li>Setup your users and groups with the appropriate permissions:
  <ul>
    <li>The &#039;Manage Maps&#039; Permission allows administrators to add/edit and delete maps</li>
    <li>The &#039;Manage Map Locations&#039; permission allows administrators to add/edit/delete points within a map</li>
  </ul>
</li>
<li>Create a map.  Give the map a name, and adjust the paramters of the particular map to meet your liking</p>
<li>Mark one of your maps as default, by clicking on the red &#039;X&#039; beside a particular map.  This is useful if you don&#039;t specify the &#039;map&#039; parameter on the tag.</li>
<li>Create one or more points within the map, either by specifying a latitude and longitude, or with an address.</li>
<li>Add the {CGGoogleMaps} tag inside the content block of a page, or inside a page template.  Then you&#039;re finished.</li>
</ul>
<br/>
<h3>Adding Points to a Map Dynamically</h3>
<p>You can use smarty to add points to a module dynamically.  You can use this functionality to build a frappr like map with multiple points that are controlled dynamically from another module (like CompanyDirectory or FrontEndUsers).</p>
<h4>The {cggm_add_dynpoint} Smarty Plugin</h4>
<p>This smarty plugin <em>(only available when CGGoogleMaps is installed)</em> allows adding a point dynamically to a specified map.</p>
<h5>Parameters:<h5>
  <ul> 
<li><strong>required</strong> - map : The ID of the map to add the point to</li>
<li><strong>required</strong> - name : The name of the point to add</li>
<li><em>optional</em> - description : The HTML content to show in the popup bubble</li>
<li><em>optional</em> - address : The address of the location you are adding.</li>
<li><em>optional</em> - lat : The latitude of the location you are adding.</li>
<li><em>optional</em> - long : The longitude of the location you are adding.</li>
<li><em>optional</em> - icon : The name of an icon to use for this point.</li>
<li><em>optional</em> - tooltip : Title text to display when hovering a point</li>
<li><em>optional</em> - sidebar_class : Optional class to associate with the sidebar list item for this point.</li>
<li><em>optional</em> - sidebar_html : Optional text to include for this marker on the sidebar.</li>
  </ul>
<br/>
<p><strong>Note:</strong> Either the lat and long parameters must be specified, or the address.</p>
<p><strong>Note:</strong> This plugin returns no direct output, and if errors occur, it will silently fail.  Success means that the point will show up on your google map.</p>
</ul>';
$lang['height'] = 'Hoogte';
$lang['help_anchor_location'] = '<strong>Opmerking:</strong> Anchor locaties specificeren de pixel locatie (in relatie tot de linkerboven hoek van de afbeelding) waar de pictogram moet komen als markeerpunt. Als er geen waarde is gegeven, wordt het midden van de pictogram gebruikt';
$lang['help_icon_url'] = 'Benoem de URL van de ge&uuml;ploade PNG afbeelding.  Deze afbeelding mag niet groter zijn dan 32x32px, en moet transparant zijn. De URL moet vanuit de root van uw website worden benoemd';
$lang['help_param_defer'] = 'Specify that all javascript tags should have the defer attribute set.  This may be useful for problems with IE7 and IE8 where Internet explorer tries to execute javascript on an incompletely rendered page. ';
$lang['help_param_map'] = 'Specificeer een ID of kaartnaam voor het weergeven van de Google Map. Als deze parameter niet wordt opgegeven, dan wordt de standaard map gebruikt.';
$lang['help_param_maptemplate'] = 'Geef de naam op van een bestaande, niet standaard (default) map sjabloon om te gebruiken voor deze output. Als deze parameter niet gespecificeerd is, zal de huidige als standaard gekenmerkte sjabloon toegepast worden.';
$lang['hide_directions'] = 'Verberg bestemmingen';
$lang['horizontal_bar'] = 'Horizontale balk';
$lang['hybrid'] = 'Kruising';
$lang['id'] = 'Id ';
$lang['icon'] = 'Pictogram';
$lang['imperial'] = 'Imperiaal';
$lang['info'] = 'Informatie';
$lang['info_address_latlong'] = 'Opmerking: Geef <strong>OF</strong> een adres in <strong>OF</strong> een breedtegraad en lengtegraad.  Als beide zijn ingegeven, zal breedtegraad/lengtegraad worden gebruikt.';
$lang['info_anchor_x'] = 'Infoscherm Anchor X pixel locatie';
$lang['info_anchor_y'] = 'Infoscherm Anchor Y pixel locatie';
$lang['info_bounds_fudge'] = 'When zoom encompass is specified you can specify a percentage <em>(in decimal)</em> by which to expand the map bounds to provide a &quot;margin&quot; around the encompassed points';
$lang['info_category_panel'] = 'Should a panel be displayed that shows the categories of all of the map points, and allow toggling map markers on and off by category';
$lang['info_center_lat'] = 'The Center latitude is optional.  If specified it will be used for centering the map.  Specify a value in decimal degrees i.e: -123.45';
$lang['info_center_lon'] = 'The Center longitude is optional.  If specified it will be used for centering the map. Specify a value in decimal degrees i.e: -123.45';
$lang['info_combine_points'] = 'If selected, points that are within a specified radius of each other will be combined into one marker on the map.  This functionality is useful if multiple entries exist at the same (or almost the same) coordinates, to ease in selection.  This functionality is independant of the map zoom level.  ';
$lang['info_controls'] = 'Moeten zoom en pan buttons worden weergegeven?';
$lang['info_controls_size'] = 'Geef de grootte op van de buttons op de kaart';
$lang['info_default_icon'] = 'The default icon is used when no other icon is specified for a map point';
$lang['info_directions'] = 'Allow the user to request directions from, or to a map point';
$lang['info_directions_dest'] = 'Specify how directions should be handled.  Should they be displayed in a new window, or in the map panel';
$lang['info_directions_units'] = 'Specify how the units should be displayed for directions.  Metric, or imperial.';
$lang['info_height'] = 'Geef de hoogte van de map op (in pixels)';
$lang['info_icon_selection'] = 'By default, which icon should be preferred for markers when the category panel is displayed';
$lang['info_info_trigger'] = 'Specify what should trigger the opening of the info window';
$lang['info_info_window'] = 'Should an information window be displayed for each map point?';
$lang['info_infowindow_height'] = 'Geef de hoogte (in pixels) op voor het informatievenster';
$lang['info_infowindow_width'] = 'Geef de breedte (in pixels) op voor het informatievenster';
$lang['info_map_type'] = 'Specify the default map type (if type controls are enabled, the user can change the type after the map is displayed)';
$lang['info_nav_control_opt'] = 'Specify the type of navigation controls for the map';
$lang['info_point_combine_fudge'] = 'The smaller the radius means that fewer points will be combined into one map marker.  Negative values are invalid.';
$lang['info_point_combine_icon'] = 'Specify an icon to use to illustrate on the map that the marker consists of multiple points that are within a small area';
$lang['info_scalecontrols'] = 'A scale can optionally be displayed in the lower right corner of the map';
$lang['info_sensor'] = 'Some browsers (particularly mobile browsers) are capable of providing latitude and longitude information.  Do you want to enable this?';
$lang['info_sidebar'] = 'Moet er een sidebar met alle punten op de kaart worden weergegeven?';
$lang['info_sv_controls'] = 'Moeten StreetView buttons worden weergegeven op de kaart?';
$lang['info_sysdflt_category_template'] = 'Systeemstandaard &quot;Categorielijst&quot; sjabloon';
$lang['info_sysdflt_dirform_template'] = 'Systeemstandaard &quot;Bestemmingsformulier&quot; sjabloon';
$lang['info_sysdflt_js_template'] = 'Systeemstandaard Javascript sjabloon';
$lang['info_sysdflt_map_template'] = 'Systeemstandaard Kaart sjabloon';
$lang['info_sysdflt_sidebar_template'] = 'Systeemstandaard Sidebar sjabloon';
$lang['info_sysdflt_template'] = 'Dit formulier geeft de mogelijkheid om de inhoud te specificeren die zal worden getoond als je een nieuw sjabloon van dit type aanmaakt. Het wijzigen van de inhoud zal geen direct effect hebben op je website.';
$lang['info_type_control_opt'] = 'Geef aan hoe de kaartbesturing moet worden weergegeven';
$lang['info_width'] = 'Geef een mapbreedte op';
$lang['infowindow_width'] = 'Breedte van informatievenster';
$lang['infowindow_height'] = 'Hoogte van informatievenster';
$lang['info_type_controls'] = 'Sta gebruiker toe om het type kaart te wijzigen?';
$lang['info_zoom'] = 'Specify an initial zoom level (note, that this parameter is ineffective if &quot;zoom encompass&quot; is used';
$lang['info_zoom_encompass'] = 'Should the zoom level of the map encompass all of the points?';
$lang['js_template'] = 'Javascript sjabloon';
$lang['large'] = 'Groot';
$lang['latitude'] = 'Breedtegraad';
$lang['latlong'] = 'Breedtegraad / Lengtegraad';
$lang['location'] = 'Locatie';
$lang['longitude'] = 'Lengtegraad';
$lang['make_default'] = 'Gebruik standaard dit pictogram';
$lang['marker_categories'] = 'Marker Categorie&euml;n';
$lang['marker_icons'] = 'Markeer Pictogram';
$lang['map'] = 'Kaart';
$lang['maps'] = 'Kaarten';
$lang['maptemplate_addedit'] = 'toevoegen/wijzigen map sjabloon';
$lang['map_name'] = 'Kaart naam';
$lang['map_template'] = 'Map Sjabloon';
$lang['map_templates'] = 'Map Sjablonen';
$lang['map_type'] = 'Kaarttype';
$lang['metric'] = 'Metrisch';
$lang['moddescription'] = 'Module om Google maps te maken';
$lang['mouseover'] = 'MuisOver';
$lang['msg_categoryadded'] = 'Categorie toegevoegd';
$lang['msg_categorydeleted'] = 'Categorie verwijderd';
$lang['msg_categoryupdated'] = 'Categorie bijgewerkt';
$lang['msg_default_icon_uchanged'] = 'De standaard pictogram is gewijzigd';
$lang['msg_icons_reset'] = 'De pictogrammen zijn terug naar de standaard instellingen';
$lang['msg_icon_removed'] = 'Pictogram verwijderd van de database.  Er zijn geen bestanden verwijderd';
$lang['msg_icon_updated'] = 'Pictogram informatie is gewijzigd';
$lang['name'] = 'Naam';
$lang['nav_control_opt'] = 'Navigatiebuttongrootte';
$lang['none'] = 'Geen';
$lang['panel'] = 'Paneel';
$lang['points'] = 'Punten';
$lang['point_combine_fudge'] = 'Benoem een radius die aangeeft wanneer punten moeten worden gecombineerd.';
$lang['point_combine_icon'] = 'Gecombineerde punten pictogram';
$lang['point_name'] = 'Punt naam';
$lang['point_type'] = 'Aanwijzer Type';
$lang['policy_cachefirst'] = 'Lees cache eerst en vervolgens het adres online zoeken';
$lang['policy_cacheonly'] = 'Altijd cache gebruiken';
$lang['policy_nocache'] = 'Nooit de cache gebruiken (alleen online opzoeken)';
$lang['postinstall'] = 'CGGoogleMaps is ge&iuml;nstalleerd';
$lang['postuninstall'] = 'De CGGoogleMaps module en alle relevante bestanden zijn verwijderd';
$lang['preferences'] = 'Eigenschappen';
$lang['prompt_bounds_fudge'] = 'Zoom Encompass Bounds Fudge';
$lang['prompt_categories'] = 'Categorie&euml;n';
$lang['prompt_directions'] = 'Bestemmingen';
$lang['prompt_from_here'] = 'Vanaf hier';
$lang['prompt_icon_selection'] = 'Pictogramselectie';
$lang['prompt_info_window'] = 'Laat informatievenster zien';
$lang['prompt_info_trigger'] = 'Info Window Trigger';
$lang['prompt_lookup_policy'] = 'Opzoekbeleid';
$lang['prompt_lookup_service'] = 'Opzoekservice';
$lang['prompt_to_here'] = 'Naar hier';
$lang['prompt_sensor'] = 'Supply Geographic location information to the map';
$lang['prompt_zoom'] = 'Zoomniveau';
$lang['really_uninstall'] = 'Weet je zeker dat je deze module wilt verwijderen?';
$lang['reset'] = 'Herstel';
$lang['reset_icons'] = 'Reset pictogrammen';
$lang['satellite'] = 'Sateliet';
$lang['scalecontrols'] = 'Laat schaal zien';
$lang['set_dflt_map'] = 'Zet kaart als standaard';
$lang['show_category_panel'] = 'Laat categoriepaneel zien';
$lang['sidebar'] = 'Geef Sidebar weer';
$lang['sidebar_template'] = 'Sidebar sjabloon';
$lang['small'] = 'Klein';
$lang['submit'] = 'Verzend';
$lang['sv_controls'] = 'Laat StreetView buttons zien';
$lang['tab_advanced'] = 'Geavanceerd';
$lang['tab_directions'] = 'Bestemmingen';
$lang['tab_jstemplate'] = 'Javascript sjabloon';
$lang['tab_settings'] = 'Instellingen';
$lang['tab_maptemplate'] = 'Map Sjabloon';
$lang['text'] = 'Tekst';
$lang['to'] = 'Naar';
$lang['type'] = 'Soort';
$lang['type_controls'] = 'Geef typebesturingsknoppen weer';
$lang['type_control_opt'] = 'Type besturingsopties';
$lang['url'] = 'Url';
$lang['use_category_icon'] = 'Kies een categoriepictogram';
$lang['use_marker_icon'] = 'Kies een markeerpictogram';
$lang['width'] = 'Breedte';
$lang['window'] = 'Venster';
$lang['zoom_encompass'] = 'Inzoom omgeving';
$lang['utma'] = '156861353.1852221271.1287479092.1294509952.1294593558.77';
$lang['utmz'] = '156861353.1294509952.76.54.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/files/34|utmcmd=referral';
$lang['qca'] = 'P0-161031897-1287479092171';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
